# MOAI, an Open Access Server Platform for Institutional Repositories

MOAI is a platform for aggregating content from different sources, and publishing it through the Open Archive Initiatives protocol for metadata harvesting. It's been built for academic institutional repositories dealing with relational metadata and asset files.

## What does it do?

The MOAI software can aggregate content from different sources, transform it and store it in a database. The contents of this database can then be published in many separate OAI feeds, each with its own configuration.

The MOAI software has a very flexible system for combining records into sets, and can use these sets in the feed configuration. It also comes with a simple yet flexible authentication scheme that can be easily customized. Besides providing authentication for the feeds, the authentication also controls the access to the assets.

## Why MOAI

MOAI has been specifically developed for universities, and contains a lot of hard-earned wisdom. The software has been in production use since 2007, and new features have been continually added. In late 2008, the software was completely refactored and packaged under the name "MOAI". You can read more about this on the MOAI History page.

MOAI is a standalone system, so it can be used in combination with any repository software that comes with an OAI feed such as Fedora Commons, EPrints or DSpace. It can also be used directly with an SQL database or just a folder of XML files.

The MOAI project takes the philosophy that every repository is different and unique, and that an institutional repository is a living thing. It is therefore never finished. Metadata is always changes, improving, and evolves. We think this is healthy.

Because of this viewpoint, the MOAI software makes it as easy as possible to add or modify parts of your repository (OAI) services stack. It tries to do this without sacrificing power, and encouraging the re-use of components.

## Features

MOAI has some interesting features not found in most OAI servers. Besides serving OAI, it can also harvest OAI. This makes it possible for MOAI to work as a pipe, where the OAI data can be reconfigured, cached, and enriched while it passes through the MOAI processing.

More specifically MOAI has the ability to:

- Harvest data from different kinds of sources
- Serve many OAI feeds from one MOAI server, each with their own configuration
- Turn metadata values into OAI sets on the fly, creating new collections
- Use OAI sets to filter records shown in a feed, configurable for each feed
- Work easily with relational data (e.g. if an author changes, the publication should also change)
- Simple and robust authentication through integration with the Apache webserver
- Serve assets via Apache while still using configurable authentication rules

In the coming period we will be adding more features and updating this page accordingly.

# MOAI Changes

## MOAI 1.1.1 (2010-09-02)

### Changes

- Fixed ID/IDref attributes in MODS format
- Fixed ZeroDivisionError in progressbar drawing of updatedb script

## MOAI 1.1.0 (2010-04-08)

### Changes

- Added new config option deleted_sets which can be used to make all resources within a specific set oai deleted within the context of a specific feed. In many cases this is preferable compared to disallowed_sets since resources will just dissapear when they are not allowed without leaving a proper deleted resource behind.
- Disable ranged HTTP requests in Apache mod_python backend. This was giving problems with acrobat plugin and its "Fast Web View" feature.
- Show records sorted on descending datestamp, instead of ascending record id, in sqlite backend.

### Changes

## MOAI 1.0.10 (2010-03-25)

### Changes

- Changed DIP:objectType to rdf:type in the didl metadata format, as required by darenet/driver/didl 3.0 format
- Added support for modification dates and accessrights in the didl format

## MOAI 1.0.9 (2010-02-16)

### Changes

- Added checking on XML compatibility in update.py, update_database_iterate(). This prevents the OAI server from crashing on invalid data.
- Fixed a minor bug in tools.py. The -d (debug) flag for the update_database script didn't halt on errors.
- Added a flush_threshold attribute to the DatabaseUpdater. This can be used to make the database flush after n records. By default the value is -1, and flushing only happens at the end of the update.
- Fixed assertion statements in content.py (gave warnings in python2.6)

## MOAI 1.0.8 (2009-16-18)

### Changes

- Added a MANIFEST.in file to make sure all files are included in the python package.

## MOAI 1.0.7 (2009-16-11)

### Changes

- Changed DIP namespace in didl metadata extension
- Fixed bug in ListMetadataFormats verb
- Uses pyoai 2.4.1, which when specifying a date (not a datetime) for the until parameter, defaults to 23:59:59 instead of 00:00:00.

## MOAI 1.0.6 (2009-08-12)

### Changes

- Fixed metadataPrefix value in didl:Resource URL. This was using didl instead of nl_didl

## MOAI 1.0.5 (2009-08-12)

- Unicode bug in Fedora provider
- Added support for mods:location/url Make url prefered identifier in oai_dc:identifier instead of uri
- Update method of Content Objects can now return False to prevent further processing of the object. The object will be logged as ignored

## MOAI 1.0.4 (2009-07-15)

### Changes

- Fixed misspelled mimeType attribute in DIDL metadata prefix

## MOAI 1.0.3 (2009-06-23)

### Changes

- Bug in ListMetadataFormats when using nl_didl prefix
- Added simple dc example profile

## MOAI 1.0.2 (2009-05-20)

### Changes

- Location in mod_python config is dynamicly extracted from Metro Server class.

## MOAI 1.0.1 (2009-05-19)

### Changes

- Fixed URL error in didl metadata prefix
- Seperated darenet specific didl extensions in nl_didl prefix

## MOAI 1.0 (2009-05-04)

### Changes

- Improved documentation
- Added description to Identify header
- More complete mods name roles
- Require newer pyoai version that gives better error responses when wrong datatime values are used in OAI requests

## MOAI 0.9.x (2009-02-01)

### Changes

- Added Apache mod_python backend
- Added basic authentication for fedora provider
- Made fedora provider datastream argument optional, if not specified the whole foxml file is returned
- Ported SQLite database backend from EUR RePub
- Renamed MetaDataPrefix classes to MetaDataFormat
- Added configurable plugin system
- Added documentation website (more info in README.txt)
- Made Fedora provider not write all files in same directory

### Changes

- OAI ListRecords with from and until dateparams where not inclusive in SQLite engine
- OAI ListSets did not return dynamic sets (added test)
- OAI GetRecord returning the same record (added test)

## MOAI 0.9 (2008-11-18)

- Initial development borrowing code and ideas from RepubXML, a repository environment build for the Erasmus Univiersity Rotterdam